<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableV2 v-bind="proTableProps" :columns="column" :showOperationColumn="false">
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { AppContainer, useTable, ProTableV2 } from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
// import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { useUser } from '@/hooks';
// import { TransferToStatusEnumText } from '@/constants';

defineOptions({
  name: 'RewardGrantRecordView',
});

const column = [
  {
    id: '1',
    enCode: 'transferToTime',
    name: '发放时间',
  },
  {
    id: '2',
    enCode: 'transferToAmount',
    name: '发放金额',
  },
  {
    id: '3',
    enCode: 'batchNo',
    name: '发放批次',
  },
  {
    id: '4',
    enCode: 'applyMonth',
    name: '发放月份',
  },
  {
    id: '4',
    enCode: 'transferToStatus',
    name: '发放状态',
  },
];

const route = useRoute();
const router = useRouter();
const id = route.params.id as string;
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });
const { userDetail } = useUser();

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.QueryParkCustomerBountyApplyInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        id: userDetail.value?.userId ?? '',
      };
      let res = await parkBountyApplyServices.getParkCustomerBountySettleList(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'settleTime', order: OrderInputType.Desc }],
    },
    columnsRenderProps: {
      transferToStatus: { type: 'enum', valueEnum: TransferToStatusEnumText },
      transferToTime: { type: 'date', format: 'YYYY-MM-DD' },
      applyMonth: { type: 'date', format: 'YYYY年MM月' },
      transferToAmount: { type: 'money' },
    },
  }
);

onMounted(async () => {
  await getList();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
